Class: SemgrepWebApp::AddProjectTagsRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/semgrep_web_app/models/add_project_tags_request.rb

Overview

AddProjectTagsRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(deployment_slug:, project_name:, tags: SKIP, additional_properties: nil) ⇒ AddProjectTagsRequest

Returns a new instance of AddProjectTagsRequest.



46
47
48
49
50
51
52
53
54
55
# File 'lib/semgrep_web_app/models/add_project_tags_request.rb', line 46

def initialize(deployment_slug:, project_name:, tags: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @deployment_slug = deployment_slug
  @project_name = project_name
  @tags = tags unless tags == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#deployment_slugString

Slug of the deployment name. Can be found at /deployments, or in your Settings in the web UI.

Returns:

  • (String)


15
16
17
# File 'lib/semgrep_web_app/models/add_project_tags_request.rb', line 15

def deployment_slug
  @deployment_slug
end

#project_nameString

Name of the project, typically the repository formatted as a path.

Returns:

  • (String)


19
20
21
# File 'lib/semgrep_web_app/models/add_project_tags_request.rb', line 19

def project_name
  @project_name
end

#tagsArray[String]

Name of the project, typically the repository formatted as a path.

Returns:

  • (Array[String])


23
24
25
# File 'lib/semgrep_web_app/models/add_project_tags_request.rb', line 23

def tags
  @tags
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/semgrep_web_app/models/add_project_tags_request.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  deployment_slug =
    hash.key?('deploymentSlug') ? hash['deploymentSlug'] : nil
  project_name = hash.key?('projectName') ? hash['projectName'] : nil
  tags = hash.key?('tags') ? hash['tags'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AddProjectTagsRequest.new(deployment_slug: deployment_slug,
                            project_name: project_name,
                            tags: tags,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/semgrep_web_app/models/add_project_tags_request.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['deployment_slug'] = 'deploymentSlug'
  @_hash['project_name'] = 'projectName'
  @_hash['tags'] = 'tags'
  @_hash
end

.nullablesObject

An array for nullable fields



42
43
44
# File 'lib/semgrep_web_app/models/add_project_tags_request.rb', line 42

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
# File 'lib/semgrep_web_app/models/add_project_tags_request.rb', line 35

def self.optionals
  %w[
    tags
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
94
# File 'lib/semgrep_web_app/models/add_project_tags_request.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} deployment_slug: #{@deployment_slug.inspect}, project_name:"\
  " #{@project_name.inspect}, tags: #{@tags.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/semgrep_web_app/models/add_project_tags_request.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} deployment_slug: #{@deployment_slug}, project_name: #{@project_name}, tags:"\
  " #{@tags}, additional_properties: #{@additional_properties}>"
end