Class: SemgrepWebApp::ApiV1DeploymentsFindingsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/semgrep_web_app/models/api_v1_deployments_findings_response.rb

Overview

ApiV1DeploymentsFindingsResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(findings: SKIP, additional_properties: nil) ⇒ ApiV1DeploymentsFindingsResponse

Returns a new instance of ApiV1DeploymentsFindingsResponse.



35
36
37
38
39
40
41
# File 'lib/semgrep_web_app/models/api_v1_deployments_findings_response.rb', line 35

def initialize(findings: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @findings = findings unless findings == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#findingsArray[Object]

TODO: Write general description for this method

Returns:

  • (Array[Object])


14
15
16
# File 'lib/semgrep_web_app/models/api_v1_deployments_findings_response.rb', line 14

def findings
  @findings
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/semgrep_web_app/models/api_v1_deployments_findings_response.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  findings = hash.key?('findings') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:ApiV1DeploymentsFindingsResponseFindings), hash['findings']
  ) : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ApiV1DeploymentsFindingsResponse.new(findings: findings,
                                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/semgrep_web_app/models/api_v1_deployments_findings_response.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['findings'] = 'findings'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/semgrep_web_app/models/api_v1_deployments_findings_response.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/semgrep_web_app/models/api_v1_deployments_findings_response.rb', line 24

def self.optionals
  %w[
    findings
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



66
67
68
69
70
71
72
# File 'lib/semgrep_web_app/models/api_v1_deployments_findings_response.rb', line 66

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/semgrep_web_app/models/api_v1_deployments_findings_response.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} findings: #{@findings.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
# File 'lib/semgrep_web_app/models/api_v1_deployments_findings_response.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} findings: #{@findings}, additional_properties: #{@additional_properties}>"
end