Class: SemgrepWebApp::Autotriage

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/semgrep_web_app/models/autotriage.rb

Overview

Triage recommendation generated by Semgrep Assistant

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(reason: SKIP, verdict: SKIP, additional_properties: nil) ⇒ Autotriage

Returns a new instance of Autotriage.



44
45
46
47
48
49
50
51
# File 'lib/semgrep_web_app/models/autotriage.rb', line 44

def initialize(reason: SKIP, verdict: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @reason = reason unless reason == SKIP
  @verdict = verdict unless verdict == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#reasonString

The reasoning for a false_positive verdict; this explains why you might want to ignore the finding. Empty string if verdict is true_positive

Returns:

  • (String)


15
16
17
# File 'lib/semgrep_web_app/models/autotriage.rb', line 15

def reason
  @reason
end

#verdictVerdict1

The verdict is true_positive if Assistant recommends fixing, false_positive if Assistant recommends ignoring this finding. AI generated decision, review carefully

Returns:



21
22
23
# File 'lib/semgrep_web_app/models/autotriage.rb', line 21

def verdict
  @verdict
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/semgrep_web_app/models/autotriage.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  reason = hash.key?('reason') ? hash['reason'] : SKIP
  verdict = hash.key?('verdict') ? hash['verdict'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  Autotriage.new(reason: reason,
                 verdict: verdict,
                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/semgrep_web_app/models/autotriage.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['reason'] = 'reason'
  @_hash['verdict'] = 'verdict'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/semgrep_web_app/models/autotriage.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
37
# File 'lib/semgrep_web_app/models/autotriage.rb', line 32

def self.optionals
  %w[
    reason
    verdict
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Autotriage | Hash)

    value against the validation is performed.



76
77
78
79
80
81
82
# File 'lib/semgrep_web_app/models/autotriage.rb', line 76

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



92
93
94
95
96
# File 'lib/semgrep_web_app/models/autotriage.rb', line 92

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} reason: #{@reason.inspect}, verdict: #{@verdict.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



85
86
87
88
89
# File 'lib/semgrep_web_app/models/autotriage.rb', line 85

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} reason: #{@reason}, verdict: #{@verdict}, additional_properties:"\
  " #{@additional_properties}>"
end