Class: SemgrepWebApp::BulkTriageResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SemgrepWebApp::BulkTriageResponse
- Defined in:
- lib/semgrep_web_app/models/bulk_triage_response.rb
Overview
BulkTriageResponse Model.
Instance Attribute Summary collapse
-
#num_triaged ⇒ Integer
Number of items updated.
-
#triaged_issues ⇒ Array[Integer]
List of triaged issue IDs.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(num_triaged:, triaged_issues:, additional_properties: nil) ⇒ BulkTriageResponse
constructor
A new instance of BulkTriageResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(num_triaged:, triaged_issues:, additional_properties: nil) ⇒ BulkTriageResponse
Returns a new instance of BulkTriageResponse.
38 39 40 41 42 43 44 45 |
# File 'lib/semgrep_web_app/models/bulk_triage_response.rb', line 38 def initialize(num_triaged:, triaged_issues:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @num_triaged = num_triaged @triaged_issues = triaged_issues @additional_properties = additional_properties end |
Instance Attribute Details
#num_triaged ⇒ Integer
Number of items updated
14 15 16 |
# File 'lib/semgrep_web_app/models/bulk_triage_response.rb', line 14 def num_triaged @num_triaged end |
#triaged_issues ⇒ Array[Integer]
List of triaged issue IDs
18 19 20 |
# File 'lib/semgrep_web_app/models/bulk_triage_response.rb', line 18 def triaged_issues @triaged_issues end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/semgrep_web_app/models/bulk_triage_response.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. num_triaged = hash.key?('num_triaged') ? hash['num_triaged'] : nil triaged_issues = hash.key?('triaged_issues') ? hash['triaged_issues'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BulkTriageResponse.new(num_triaged: num_triaged, triaged_issues: triaged_issues, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/semgrep_web_app/models/bulk_triage_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['num_triaged'] = 'num_triaged' @_hash['triaged_issues'] = 'triaged_issues' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/semgrep_web_app/models/bulk_triage_response.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/semgrep_web_app/models/bulk_triage_response.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/semgrep_web_app/models/bulk_triage_response.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} num_triaged: #{@num_triaged.inspect}, triaged_issues:"\ " #{@triaged_issues.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/semgrep_web_app/models/bulk_triage_response.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} num_triaged: #{@num_triaged}, triaged_issues: #{@triaged_issues},"\ " additional_properties: #{@additional_properties}>" end |