Class: SemgrepWebApp::ClickToFixFailure
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SemgrepWebApp::ClickToFixFailure
- Defined in:
- lib/semgrep_web_app/models/click_to_fix_failure.rb
Overview
A failed PR creation attempt by Semgrep's Click to Fix feature
Instance Attribute Summary collapse
-
#created_at ⇒ String
When this failure occurred.
-
#reason ⇒ String
Reason for the PR creation failure.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(created_at: SKIP, reason: SKIP, additional_properties: nil) ⇒ ClickToFixFailure
constructor
A new instance of ClickToFixFailure.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(created_at: SKIP, reason: SKIP, additional_properties: nil) ⇒ ClickToFixFailure
Returns a new instance of ClickToFixFailure.
41 42 43 44 45 46 47 48 |
# File 'lib/semgrep_web_app/models/click_to_fix_failure.rb', line 41 def initialize(created_at: SKIP, reason: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @created_at = created_at unless created_at == SKIP @reason = reason unless reason == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#created_at ⇒ String
When this failure occurred
14 15 16 |
# File 'lib/semgrep_web_app/models/click_to_fix_failure.rb', line 14 def created_at @created_at end |
#reason ⇒ String
Reason for the PR creation failure
18 19 20 |
# File 'lib/semgrep_web_app/models/click_to_fix_failure.rb', line 18 def reason @reason end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/semgrep_web_app/models/click_to_fix_failure.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. created_at = hash.key?('created_at') ? hash['created_at'] : SKIP reason = hash.key?('reason') ? hash['reason'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ClickToFixFailure.new(created_at: created_at, reason: reason, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/semgrep_web_app/models/click_to_fix_failure.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['created_at'] = 'created_at' @_hash['reason'] = 'reason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/semgrep_web_app/models/click_to_fix_failure.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/semgrep_web_app/models/click_to_fix_failure.rb', line 29 def self.optionals %w[ created_at reason ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
73 74 75 76 77 78 79 |
# File 'lib/semgrep_web_app/models/click_to_fix_failure.rb', line 73 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/semgrep_web_app/models/click_to_fix_failure.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} created_at: #{@created_at.inspect}, reason: #{@reason.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/semgrep_web_app/models/click_to_fix_failure.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} created_at: #{@created_at}, reason: #{@reason}, additional_properties:"\ " #{@additional_properties}>" end |