Class: SemgrepWebApp::EpssScore
- Defined in:
- lib/semgrep_web_app/models/epss_score.rb
Overview
The score assigned by FIRST.org's Exploitation Probability Scoring System
Instance Attribute Summary collapse
-
#percentile ⇒ Float
This EPSS score's percentile among all EPSS scores, from 0 to 1.
-
#score ⇒ Float
The explotation probability, from 0 to 1.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(percentile: SKIP, score: SKIP, additional_properties: nil) ⇒ EpssScore
constructor
A new instance of EpssScore.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(percentile: SKIP, score: SKIP, additional_properties: nil) ⇒ EpssScore
Returns a new instance of EpssScore.
41 42 43 44 45 46 47 48 |
# File 'lib/semgrep_web_app/models/epss_score.rb', line 41 def initialize(percentile: SKIP, score: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @percentile = percentile unless percentile == SKIP @score = score unless score == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#percentile ⇒ Float
This EPSS score's percentile among all EPSS scores, from 0 to 1
14 15 16 |
# File 'lib/semgrep_web_app/models/epss_score.rb', line 14 def percentile @percentile end |
#score ⇒ Float
The explotation probability, from 0 to 1
18 19 20 |
# File 'lib/semgrep_web_app/models/epss_score.rb', line 18 def score @score end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/semgrep_web_app/models/epss_score.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. percentile = hash.key?('percentile') ? hash['percentile'] : SKIP score = hash.key?('score') ? hash['score'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. EpssScore.new(percentile: percentile, score: score, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/semgrep_web_app/models/epss_score.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['percentile'] = 'percentile' @_hash['score'] = 'score' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/semgrep_web_app/models/epss_score.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/semgrep_web_app/models/epss_score.rb', line 29 def self.optionals %w[ percentile score ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
73 74 75 76 77 78 79 |
# File 'lib/semgrep_web_app/models/epss_score.rb', line 73 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/semgrep_web_app/models/epss_score.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} percentile: #{@percentile.inspect}, score: #{@score.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/semgrep_web_app/models/epss_score.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} percentile: #{@percentile}, score: #{@score}, additional_properties:"\ " #{@additional_properties}>" end |