Class: SemgrepWebApp::LinkTicketRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/semgrep_web_app/models/link_ticket_request.rb

Overview

Link ticket request

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(deployment_id:, issue_ids:, ticket_url:, additional_properties: nil) ⇒ LinkTicketRequest

Returns a new instance of LinkTicketRequest.



45
46
47
48
49
50
51
52
53
54
# File 'lib/semgrep_web_app/models/link_ticket_request.rb', line 45

def initialize(deployment_id:, issue_ids:, ticket_url:,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @deployment_id = deployment_id
  @issue_ids = issue_ids
  @ticket_url = ticket_url
  @additional_properties = additional_properties
end

Instance Attribute Details

#deployment_idString

Deployment ID. Can be found at /deployments, or in your Settings in the web UI.

Returns:

  • (String)


15
16
17
# File 'lib/semgrep_web_app/models/link_ticket_request.rb', line 15

def deployment_id
  @deployment_id
end

#issue_idsArray[String]

An array of Semgrep finding IDs to link the ticket to.

Returns:

  • (Array[String])


19
20
21
# File 'lib/semgrep_web_app/models/link_ticket_request.rb', line 19

def issue_ids
  @issue_ids
end

#ticket_urlString

The URL of the external ticket to link (e.g. https://myorg.atlassian.net/browse/SEC-123).

Returns:

  • (String)


24
25
26
# File 'lib/semgrep_web_app/models/link_ticket_request.rb', line 24

def ticket_url
  @ticket_url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/semgrep_web_app/models/link_ticket_request.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  deployment_id = hash.key?('deploymentId') ? hash['deploymentId'] : nil
  issue_ids = hash.key?('issue_ids') ? hash['issue_ids'] : nil
  ticket_url = hash.key?('ticket_url') ? hash['ticket_url'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LinkTicketRequest.new(deployment_id: deployment_id,
                        issue_ids: issue_ids,
                        ticket_url: ticket_url,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/semgrep_web_app/models/link_ticket_request.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['deployment_id'] = 'deploymentId'
  @_hash['issue_ids'] = 'issue_ids'
  @_hash['ticket_url'] = 'ticket_url'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/semgrep_web_app/models/link_ticket_request.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
# File 'lib/semgrep_web_app/models/link_ticket_request.rb', line 36

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
91
# File 'lib/semgrep_web_app/models/link_ticket_request.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} deployment_id: #{@deployment_id.inspect}, issue_ids: #{@issue_ids.inspect},"\
  " ticket_url: #{@ticket_url.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
84
# File 'lib/semgrep_web_app/models/link_ticket_request.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} deployment_id: #{@deployment_id}, issue_ids: #{@issue_ids}, ticket_url:"\
  " #{@ticket_url}, additional_properties: #{@additional_properties}>"
end