Class: SemgrepWebApp::ManagedScanConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SemgrepWebApp::ManagedScanConfig
- Defined in:
- lib/semgrep_web_app/models/managed_scan_config.rb
Overview
[Beta] Configuration of Semgrep Managed Scans for the project, if relevant.
Instance Attribute Summary collapse
-
#diff_scan ⇒ ProtosOpenapiV1DiffScan
TODO: Write general description for this method.
-
#full_scan ⇒ ProtosOpenapiV1FullScan
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(diff_scan: SKIP, full_scan: SKIP, additional_properties: nil) ⇒ ManagedScanConfig
constructor
A new instance of ManagedScanConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(diff_scan: SKIP, full_scan: SKIP, additional_properties: nil) ⇒ ManagedScanConfig
Returns a new instance of ManagedScanConfig.
41 42 43 44 45 46 47 48 |
# File 'lib/semgrep_web_app/models/managed_scan_config.rb', line 41 def initialize(diff_scan: SKIP, full_scan: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @diff_scan = diff_scan unless diff_scan == SKIP @full_scan = full_scan unless full_scan == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#diff_scan ⇒ ProtosOpenapiV1DiffScan
TODO: Write general description for this method
14 15 16 |
# File 'lib/semgrep_web_app/models/managed_scan_config.rb', line 14 def diff_scan @diff_scan end |
#full_scan ⇒ ProtosOpenapiV1FullScan
TODO: Write general description for this method
18 19 20 |
# File 'lib/semgrep_web_app/models/managed_scan_config.rb', line 18 def full_scan @full_scan end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/semgrep_web_app/models/managed_scan_config.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. diff_scan = ProtosOpenapiV1DiffScan.from_hash(hash['diff_scan']) if hash['diff_scan'] full_scan = ProtosOpenapiV1FullScan.from_hash(hash['full_scan']) if hash['full_scan'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ManagedScanConfig.new(diff_scan: diff_scan, full_scan: full_scan, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/semgrep_web_app/models/managed_scan_config.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['diff_scan'] = 'diff_scan' @_hash['full_scan'] = 'full_scan' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/semgrep_web_app/models/managed_scan_config.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/semgrep_web_app/models/managed_scan_config.rb', line 29 def self.optionals %w[ diff_scan full_scan ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/semgrep_web_app/models/managed_scan_config.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} diff_scan: #{@diff_scan.inspect}, full_scan: #{@full_scan.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/semgrep_web_app/models/managed_scan_config.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} diff_scan: #{@diff_scan}, full_scan: #{@full_scan}, additional_properties:"\ " #{@additional_properties}>" end |