Class: SemgrepWebApp::PolicyReference

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/semgrep_web_app/models/policy_reference.rb

Overview

Reference to a policy, with some basic information. If null, then the information does not exist or lacks integrity (older or broken scans)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id: SKIP, name: SKIP, slug: SKIP, additional_properties: nil) ⇒ PolicyReference

Returns a new instance of PolicyReference.



48
49
50
51
52
53
54
55
56
# File 'lib/semgrep_web_app/models/policy_reference.rb', line 48

def initialize(id: SKIP, name: SKIP, slug: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @id = id unless id == SKIP
  @name = name unless name == SKIP
  @slug = slug unless slug == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#idInteger

Unique numerical identifier of the policy

Returns:

  • (Integer)


15
16
17
# File 'lib/semgrep_web_app/models/policy_reference.rb', line 15

def id
  @id
end

#nameString

Human readable name

Returns:

  • (String)


19
20
21
# File 'lib/semgrep_web_app/models/policy_reference.rb', line 19

def name
  @name
end

#slugString

Sanitized machine-readable name

Returns:

  • (String)


23
24
25
# File 'lib/semgrep_web_app/models/policy_reference.rb', line 23

def slug
  @slug
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/semgrep_web_app/models/policy_reference.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP
  name = hash.key?('name') ? hash['name'] : SKIP
  slug = hash.key?('slug') ? hash['slug'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PolicyReference.new(id: id,
                      name: name,
                      slug: slug,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/semgrep_web_app/models/policy_reference.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['name'] = 'name'
  @_hash['slug'] = 'slug'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/semgrep_web_app/models/policy_reference.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/semgrep_web_app/models/policy_reference.rb', line 35

def self.optionals
  %w[
    id
    name
    slug
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (PolicyReference | Hash)

    value against the validation is performed.



83
84
85
86
87
88
89
# File 'lib/semgrep_web_app/models/policy_reference.rb', line 83

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/semgrep_web_app/models/policy_reference.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}, slug: #{@slug.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/semgrep_web_app/models/policy_reference.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, name: #{@name}, slug: #{@slug}, additional_properties:"\
  " #{@additional_properties}>"
end