Class: SemgrepWebApp::ProtosOpenapiV1CreateTicketResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SemgrepWebApp::ProtosOpenapiV1CreateTicketResponse
- Defined in:
- lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response.rb
Overview
ProtosOpenapiV1CreateTicketResponse Model.
Instance Attribute Summary collapse
-
#failed ⇒ Array[ProtosOpenapiV1CreateTicketResponseTicketCreationFailed]
List of issues where ticket creation failed.
-
#skipped ⇒ Array[ProtosOpenapiV1CreateTicketResponseTicketCreationSkipped]
List of issues that were skipped.
-
#succeeded ⇒ Array[ProtosOpenapiV1CreateTicketResponseTicketCreationSuccess]
List of successfully created tickets.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(failed: SKIP, skipped: SKIP, succeeded: SKIP, additional_properties: nil) ⇒ ProtosOpenapiV1CreateTicketResponse
constructor
A new instance of ProtosOpenapiV1CreateTicketResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(failed: SKIP, skipped: SKIP, succeeded: SKIP, additional_properties: nil) ⇒ ProtosOpenapiV1CreateTicketResponse
Returns a new instance of ProtosOpenapiV1CreateTicketResponse.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response.rb', line 48 def initialize(failed: SKIP, skipped: SKIP, succeeded: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @failed = failed unless failed == SKIP @skipped = skipped unless skipped == SKIP @succeeded = succeeded unless succeeded == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#failed ⇒ Array[ProtosOpenapiV1CreateTicketResponseTicketCreationFailed]
List of issues where ticket creation failed. This list may include issues that were skipped because they exceed the specified limit.
15 16 17 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response.rb', line 15 def failed @failed end |
#skipped ⇒ Array[ProtosOpenapiV1CreateTicketResponseTicketCreationSkipped]
List of issues that were skipped
19 20 21 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response.rb', line 19 def skipped @skipped end |
#succeeded ⇒ Array[ProtosOpenapiV1CreateTicketResponseTicketCreationSuccess]
List of successfully created tickets
23 24 25 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response.rb', line 23 def succeeded @succeeded end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it failed = nil unless hash['failed'].nil? failed = [] hash['failed'].each do |structure| failed << (ProtosOpenapiV1CreateTicketResponseTicketCreationFailed.from_hash(structure) if structure) end end failed = SKIP unless hash.key?('failed') # Parameter is an array, so we need to iterate through it skipped = nil unless hash['skipped'].nil? skipped = [] hash['skipped'].each do |structure| skipped << (ProtosOpenapiV1CreateTicketResponseTicketCreationSkipped.from_hash(structure) if structure) end end skipped = SKIP unless hash.key?('skipped') # Parameter is an array, so we need to iterate through it succeeded = nil unless hash['succeeded'].nil? succeeded = [] hash['succeeded'].each do |structure| succeeded << (ProtosOpenapiV1CreateTicketResponseTicketCreationSuccess.from_hash(structure) if structure) end end succeeded = SKIP unless hash.key?('succeeded') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProtosOpenapiV1CreateTicketResponse.new(failed: failed, skipped: skipped, succeeded: succeeded, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['failed'] = 'failed' @_hash['skipped'] = 'skipped' @_hash['succeeded'] = 'succeeded' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response.rb', line 35 def self.optionals %w[ failed skipped succeeded ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
117 118 119 120 121 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response.rb', line 117 def inspect class_name = self.class.name.split('::').last "<#{class_name} failed: #{@failed.inspect}, skipped: #{@skipped.inspect}, succeeded:"\ " #{@succeeded.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
110 111 112 113 114 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response.rb', line 110 def to_s class_name = self.class.name.split('::').last "<#{class_name} failed: #{@failed}, skipped: #{@skipped}, succeeded: #{@succeeded},"\ " additional_properties: #{@additional_properties}>" end |