Class: SemgrepWebApp::ProtosOpenapiV1CreateTicketResponseTicketCreationFailed
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SemgrepWebApp::ProtosOpenapiV1CreateTicketResponseTicketCreationFailed
- Defined in:
- lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_failed.rb
Overview
ProtosOpenapiV1CreateTicketResponseTicketCreationFailed Model.
Instance Attribute Summary collapse
-
#error ⇒ String
The error message for the failure.
-
#issue_ids ⇒ Array[Integer]
List of issue IDs.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(error: SKIP, issue_ids: SKIP, additional_properties: nil) ⇒ ProtosOpenapiV1CreateTicketResponseTicketCreationFailed
constructor
A new instance of ProtosOpenapiV1CreateTicketResponseTicketCreationFailed.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(error: SKIP, issue_ids: SKIP, additional_properties: nil) ⇒ ProtosOpenapiV1CreateTicketResponseTicketCreationFailed
Returns a new instance of ProtosOpenapiV1CreateTicketResponseTicketCreationFailed.
41 42 43 44 45 46 47 48 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_failed.rb', line 41 def initialize(error: SKIP, issue_ids: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @error = error unless error == SKIP @issue_ids = issue_ids unless issue_ids == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#error ⇒ String
The error message for the failure
14 15 16 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_failed.rb', line 14 def error @error end |
#issue_ids ⇒ Array[Integer]
List of issue IDs
18 19 20 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_failed.rb', line 18 def issue_ids @issue_ids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_failed.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. error = hash.key?('error') ? hash['error'] : SKIP issue_ids = hash.key?('issue_ids') ? hash['issue_ids'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProtosOpenapiV1CreateTicketResponseTicketCreationFailed.new(error: error, issue_ids: issue_ids, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_failed.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['error'] = 'error' @_hash['issue_ids'] = 'issue_ids' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_failed.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_failed.rb', line 29 def self.optionals %w[ error issue_ids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_failed.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} error: #{@error.inspect}, issue_ids: #{@issue_ids.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_failed.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} error: #{@error}, issue_ids: #{@issue_ids}, additional_properties:"\ " #{@additional_properties}>" end |