Class: SemgrepWebApp::ProtosOpenapiV1ListSecretsPathResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/semgrep_web_app/models/protos_openapi_v1_list_secrets_path_response.rb

Overview

ProtosOpenapiV1ListSecretsPathResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(cursor: SKIP, findings: SKIP, previous: SKIP, additional_properties: nil) ⇒ ProtosOpenapiV1ListSecretsPathResponse

Returns a new instance of ProtosOpenapiV1ListSecretsPathResponse.



47
48
49
50
51
52
53
54
55
56
# File 'lib/semgrep_web_app/models/protos_openapi_v1_list_secrets_path_response.rb', line 47

def initialize(cursor: SKIP, findings: SKIP, previous: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @cursor = cursor unless cursor == SKIP
  @findings = findings unless findings == SKIP
  @previous = previous unless previous == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#cursorString

Cursor to paginate through the results.

Returns:

  • (String)


14
15
16
# File 'lib/semgrep_web_app/models/protos_openapi_v1_list_secrets_path_response.rb', line 14

def cursor
  @cursor
end

#findingsArray[ProtosSecretsV1SecretsFinding]

List of Secrets associated with the given Deployment.

Returns:



18
19
20
# File 'lib/semgrep_web_app/models/protos_openapi_v1_list_secrets_path_response.rb', line 18

def findings
  @findings
end

#previousString

Cursor to paginate backwards through the results.

Returns:

  • (String)


22
23
24
# File 'lib/semgrep_web_app/models/protos_openapi_v1_list_secrets_path_response.rb', line 22

def previous
  @previous
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/semgrep_web_app/models/protos_openapi_v1_list_secrets_path_response.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  cursor = hash.key?('cursor') ? hash['cursor'] : SKIP
  # Parameter is an array, so we need to iterate through it
  findings = nil
  unless hash['findings'].nil?
    findings = []
    hash['findings'].each do |structure|
      findings << (ProtosSecretsV1SecretsFinding.from_hash(structure) if structure)
    end
  end

  findings = SKIP unless hash.key?('findings')
  previous = hash.key?('previous') ? hash['previous'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProtosOpenapiV1ListSecretsPathResponse.new(cursor: cursor,
                                             findings: findings,
                                             previous: previous,
                                             additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/semgrep_web_app/models/protos_openapi_v1_list_secrets_path_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['cursor'] = 'cursor'
  @_hash['findings'] = 'findings'
  @_hash['previous'] = 'previous'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/semgrep_web_app/models/protos_openapi_v1_list_secrets_path_response.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/semgrep_web_app/models/protos_openapi_v1_list_secrets_path_response.rb', line 34

def self.optionals
  %w[
    cursor
    findings
    previous
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
# File 'lib/semgrep_web_app/models/protos_openapi_v1_list_secrets_path_response.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} cursor: #{@cursor.inspect}, findings: #{@findings.inspect}, previous:"\
  " #{@previous.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/semgrep_web_app/models/protos_openapi_v1_list_secrets_path_response.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} cursor: #{@cursor}, findings: #{@findings}, previous: #{@previous},"\
  " additional_properties: #{@additional_properties}>"
end