Class: SemgrepWebApp::ProtosOpenapiV1UnlinkTicketResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/semgrep_web_app/models/protos_openapi_v1_unlink_ticket_response.rb

Overview

ProtosOpenapiV1UnlinkTicketResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(unlinked_issue_ids: SKIP, additional_properties: nil) ⇒ ProtosOpenapiV1UnlinkTicketResponse

Returns a new instance of ProtosOpenapiV1UnlinkTicketResponse.



35
36
37
38
39
40
41
# File 'lib/semgrep_web_app/models/protos_openapi_v1_unlink_ticket_response.rb', line 35

def initialize(unlinked_issue_ids: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @unlinked_issue_ids = unlinked_issue_ids unless unlinked_issue_ids == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#unlinked_issue_idsArray[String]

List of finding IDs that were successfully unlinked from their tickets

Returns:

  • (Array[String])


14
15
16
# File 'lib/semgrep_web_app/models/protos_openapi_v1_unlink_ticket_response.rb', line 14

def unlinked_issue_ids
  @unlinked_issue_ids
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/semgrep_web_app/models/protos_openapi_v1_unlink_ticket_response.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  unlinked_issue_ids =
    hash.key?('unlinked_issue_ids') ? hash['unlinked_issue_ids'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProtosOpenapiV1UnlinkTicketResponse.new(unlinked_issue_ids: unlinked_issue_ids,
                                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/semgrep_web_app/models/protos_openapi_v1_unlink_ticket_response.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['unlinked_issue_ids'] = 'unlinked_issue_ids'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/semgrep_web_app/models/protos_openapi_v1_unlink_ticket_response.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/semgrep_web_app/models/protos_openapi_v1_unlink_ticket_response.rb', line 24

def self.optionals
  %w[
    unlinked_issue_ids
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
75
# File 'lib/semgrep_web_app/models/protos_openapi_v1_unlink_ticket_response.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} unlinked_issue_ids: #{@unlinked_issue_ids.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



64
65
66
67
68
# File 'lib/semgrep_web_app/models/protos_openapi_v1_unlink_ticket_response.rb', line 64

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} unlinked_issue_ids: #{@unlinked_issue_ids}, additional_properties:"\
  " #{@additional_properties}>"
end