Class: SemgrepWebApp::ProtosOpenapiV1UpdatePolicyResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SemgrepWebApp::ProtosOpenapiV1UpdatePolicyResponse
- Defined in:
- lib/semgrep_web_app/models/protos_openapi_v1_update_policy_response.rb
Overview
ProtosOpenapiV1UpdatePolicyResponse Model.
Instance Attribute Summary collapse
-
#policy_id ⇒ String
Policy ID (numeric).
-
#updated_rule ⇒ Rule
Policy ID (numeric).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(policy_id: SKIP, updated_rule: SKIP, additional_properties: nil) ⇒ ProtosOpenapiV1UpdatePolicyResponse
constructor
A new instance of ProtosOpenapiV1UpdatePolicyResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(policy_id: SKIP, updated_rule: SKIP, additional_properties: nil) ⇒ ProtosOpenapiV1UpdatePolicyResponse
Returns a new instance of ProtosOpenapiV1UpdatePolicyResponse.
43 44 45 46 47 48 49 50 51 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_update_policy_response.rb', line 43 def initialize(policy_id: SKIP, updated_rule: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @policy_id = policy_id unless policy_id == SKIP @updated_rule = updated_rule unless updated_rule == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#policy_id ⇒ String
Policy ID (numeric). Example: 456. Can be found at
/deployments/{deploymentId}/policies.
15 16 17 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_update_policy_response.rb', line 15 def policy_id @policy_id end |
#updated_rule ⇒ Rule
Policy ID (numeric). Example: 456. Can be found at
/deployments/{deploymentId}/policies.
20 21 22 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_update_policy_response.rb', line 20 def updated_rule @updated_rule end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_update_policy_response.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. policy_id = hash.key?('policyId') ? hash['policyId'] : SKIP updated_rule = Rule.from_hash(hash['updatedRule']) if hash['updatedRule'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ProtosOpenapiV1UpdatePolicyResponse.new(policy_id: policy_id, updated_rule: updated_rule, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_update_policy_response.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['policy_id'] = 'policyId' @_hash['updated_rule'] = 'updatedRule' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_update_policy_response.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_update_policy_response.rb', line 31 def self.optionals %w[ policy_id updated_rule ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_update_policy_response.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} policy_id: #{@policy_id.inspect}, updated_rule: #{@updated_rule.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/semgrep_web_app/models/protos_openapi_v1_update_policy_response.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} policy_id: #{@policy_id}, updated_rule: #{@updated_rule},"\ " additional_properties: #{@additional_properties}>" end |