Class: SemgrepWebApp::ProtosScaV1Dependency

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/semgrep_web_app/models/protos_sca_v1_dependency.rb

Overview

A specific dependency.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name: SKIP, version_specifier: SKIP, additional_properties: nil) ⇒ ProtosScaV1Dependency

Returns a new instance of ProtosScaV1Dependency.



41
42
43
44
45
46
47
48
49
# File 'lib/semgrep_web_app/models/protos_sca_v1_dependency.rb', line 41

def initialize(name: SKIP, version_specifier: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name unless name == SKIP
  @version_specifier = version_specifier unless version_specifier == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#nameString

String identifier of dependency

Returns:

  • (String)


14
15
16
# File 'lib/semgrep_web_app/models/protos_sca_v1_dependency.rb', line 14

def name
  @name
end

#version_specifierString

Version specifier of dependency.

Returns:

  • (String)


18
19
20
# File 'lib/semgrep_web_app/models/protos_sca_v1_dependency.rb', line 18

def version_specifier
  @version_specifier
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/semgrep_web_app/models/protos_sca_v1_dependency.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP
  version_specifier =
    hash.key?('versionSpecifier') ? hash['versionSpecifier'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProtosScaV1Dependency.new(name: name,
                            version_specifier: version_specifier,
                            additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/semgrep_web_app/models/protos_sca_v1_dependency.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['version_specifier'] = 'versionSpecifier'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/semgrep_web_app/models/protos_sca_v1_dependency.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/semgrep_web_app/models/protos_sca_v1_dependency.rb', line 29

def self.optionals
  %w[
    name
    version_specifier
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/semgrep_web_app/models/protos_sca_v1_dependency.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, version_specifier: #{@version_specifier.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



74
75
76
77
78
# File 'lib/semgrep_web_app/models/protos_sca_v1_dependency.rb', line 74

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, version_specifier: #{@version_specifier},"\
  " additional_properties: #{@additional_properties}>"
end