Class: SemgrepWebApp::ProtosScaV1SbomMetadataSupplier

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/semgrep_web_app/models/protos_sca_v1_sbom_metadata_supplier.rb

Overview

ProtosScaV1SbomMetadataSupplier Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(contact: SKIP, name: SKIP, url: SKIP, additional_properties: nil) ⇒ ProtosScaV1SbomMetadataSupplier

Returns a new instance of ProtosScaV1SbomMetadataSupplier.



47
48
49
50
51
52
53
54
55
56
# File 'lib/semgrep_web_app/models/protos_sca_v1_sbom_metadata_supplier.rb', line 47

def initialize(contact: SKIP, name: SKIP, url: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @contact = contact unless contact == SKIP
  @name = name unless name == SKIP
  @url = url unless url == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#contactProtosScaV1SbomMetadataContact

TODO: Write general description for this method



14
15
16
# File 'lib/semgrep_web_app/models/protos_sca_v1_sbom_metadata_supplier.rb', line 14

def contact
  @contact
end

#nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/semgrep_web_app/models/protos_sca_v1_sbom_metadata_supplier.rb', line 18

def name
  @name
end

#urlString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/semgrep_web_app/models/protos_sca_v1_sbom_metadata_supplier.rb', line 22

def url
  @url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/semgrep_web_app/models/protos_sca_v1_sbom_metadata_supplier.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  contact = ProtosScaV1SbomMetadataContact.from_hash(hash['contact']) if hash['contact']
  name = hash.key?('name') ? hash['name'] : SKIP
  url = hash.key?('url') ? hash['url'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProtosScaV1SbomMetadataSupplier.new(contact: contact,
                                      name: name,
                                      url: url,
                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/semgrep_web_app/models/protos_sca_v1_sbom_metadata_supplier.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['contact'] = 'contact'
  @_hash['name'] = 'name'
  @_hash['url'] = 'url'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/semgrep_web_app/models/protos_sca_v1_sbom_metadata_supplier.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/semgrep_web_app/models/protos_sca_v1_sbom_metadata_supplier.rb', line 34

def self.optionals
  %w[
    contact
    name
    url
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/semgrep_web_app/models/protos_sca_v1_sbom_metadata_supplier.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} contact: #{@contact.inspect}, name: #{@name.inspect}, url: #{@url.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/semgrep_web_app/models/protos_sca_v1_sbom_metadata_supplier.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} contact: #{@contact}, name: #{@name}, url: #{@url}, additional_properties:"\
  " #{@additional_properties}>"
end