Class: SemgrepWebApp::ProtosScanV1ScanFindingsCounts

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/semgrep_web_app/models/protos_scan_v1_scan_findings_counts.rb

Overview

ProtosScanV1ScanFindingsCounts Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(code: SKIP, secrets: SKIP, supply_chain: SKIP, total: SKIP, additional_properties: nil) ⇒ ProtosScanV1ScanFindingsCounts

Returns a new instance of ProtosScanV1ScanFindingsCounts.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/semgrep_web_app/models/protos_scan_v1_scan_findings_counts.rb', line 53

def initialize(code: SKIP, secrets: SKIP, supply_chain: SKIP, total: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @code = code unless code == SKIP
  @secrets = secrets unless secrets == SKIP
  @supply_chain = supply_chain unless supply_chain == SKIP
  @total = total unless total == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#codeString

Total number of Code findings in the scan

Returns:

  • (String)


14
15
16
# File 'lib/semgrep_web_app/models/protos_scan_v1_scan_findings_counts.rb', line 14

def code
  @code
end

#secretsString

Total number of Secrets findings in the scan

Returns:

  • (String)


18
19
20
# File 'lib/semgrep_web_app/models/protos_scan_v1_scan_findings_counts.rb', line 18

def secrets
  @secrets
end

#supply_chainString

Total number of Supply Chain findings in the scan

Returns:

  • (String)


22
23
24
# File 'lib/semgrep_web_app/models/protos_scan_v1_scan_findings_counts.rb', line 22

def supply_chain
  @supply_chain
end

#totalString

Total number of findings in the scan

Returns:

  • (String)


26
27
28
# File 'lib/semgrep_web_app/models/protos_scan_v1_scan_findings_counts.rb', line 26

def total
  @total
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/semgrep_web_app/models/protos_scan_v1_scan_findings_counts.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  code = hash.key?('code') ? hash['code'] : SKIP
  secrets = hash.key?('secrets') ? hash['secrets'] : SKIP
  supply_chain = hash.key?('supply_chain') ? hash['supply_chain'] : SKIP
  total = hash.key?('total') ? hash['total'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProtosScanV1ScanFindingsCounts.new(code: code,
                                     secrets: secrets,
                                     supply_chain: supply_chain,
                                     total: total,
                                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/semgrep_web_app/models/protos_scan_v1_scan_findings_counts.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['code'] = 'code'
  @_hash['secrets'] = 'secrets'
  @_hash['supply_chain'] = 'supply_chain'
  @_hash['total'] = 'total'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/semgrep_web_app/models/protos_scan_v1_scan_findings_counts.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/semgrep_web_app/models/protos_scan_v1_scan_findings_counts.rb', line 39

def self.optionals
  %w[
    code
    secrets
    supply_chain
    total
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/semgrep_web_app/models/protos_scan_v1_scan_findings_counts.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code.inspect}, secrets: #{@secrets.inspect}, supply_chain:"\
  " #{@supply_chain.inspect}, total: #{@total.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/semgrep_web_app/models/protos_scan_v1_scan_findings_counts.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code}, secrets: #{@secrets}, supply_chain: #{@supply_chain},"\
  " total: #{@total}, additional_properties: #{@additional_properties}>"
end