Class: SemgrepWebApp::ProtosTicketingV1ExternalTicket

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/semgrep_web_app/models/protos_ticketing_v1_external_ticket.rb

Overview

ProtosTicketingV1ExternalTicket Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(external_slug: SKIP, id: SKIP, linked_issue_ids: SKIP, url: SKIP, additional_properties: nil) ⇒ ProtosTicketingV1ExternalTicket

Returns a new instance of ProtosTicketingV1ExternalTicket.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/semgrep_web_app/models/protos_ticketing_v1_external_ticket.rb', line 53

def initialize(external_slug: SKIP, id: SKIP, linked_issue_ids: SKIP,
               url: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @external_slug = external_slug unless external_slug == SKIP
  @id = id unless id == SKIP
  @linked_issue_ids = linked_issue_ids unless linked_issue_ids == SKIP
  @url = url unless url == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#external_slugString

Identifier of the external ticket (e.g. for Jira, something like OPS-158).

Returns:

  • (String)


14
15
16
# File 'lib/semgrep_web_app/models/protos_ticketing_v1_external_ticket.rb', line 14

def external_slug
  @external_slug
end

#idString

Nango ticket id

Returns:

  • (String)


18
19
20
# File 'lib/semgrep_web_app/models/protos_ticketing_v1_external_ticket.rb', line 18

def id
  @id
end

#linked_issue_idsArray[String]

Semgrep issue ids that are linked to this external ticket

Returns:

  • (Array[String])


22
23
24
# File 'lib/semgrep_web_app/models/protos_ticketing_v1_external_ticket.rb', line 22

def linked_issue_ids
  @linked_issue_ids
end

#urlString

URL of the external ticket.

Returns:

  • (String)


26
27
28
# File 'lib/semgrep_web_app/models/protos_ticketing_v1_external_ticket.rb', line 26

def url
  @url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/semgrep_web_app/models/protos_ticketing_v1_external_ticket.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  external_slug = hash.key?('externalSlug') ? hash['externalSlug'] : SKIP
  id = hash.key?('id') ? hash['id'] : SKIP
  linked_issue_ids =
    hash.key?('linkedIssueIds') ? hash['linkedIssueIds'] : SKIP
  url = hash.key?('url') ? hash['url'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProtosTicketingV1ExternalTicket.new(external_slug: external_slug,
                                      id: id,
                                      linked_issue_ids: linked_issue_ids,
                                      url: url,
                                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/semgrep_web_app/models/protos_ticketing_v1_external_ticket.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['external_slug'] = 'externalSlug'
  @_hash['id'] = 'id'
  @_hash['linked_issue_ids'] = 'linkedIssueIds'
  @_hash['url'] = 'url'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/semgrep_web_app/models/protos_ticketing_v1_external_ticket.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/semgrep_web_app/models/protos_ticketing_v1_external_ticket.rb', line 39

def self.optionals
  %w[
    external_slug
    id
    linked_issue_ids
    url
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
104
# File 'lib/semgrep_web_app/models/protos_ticketing_v1_external_ticket.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} external_slug: #{@external_slug.inspect}, id: #{@id.inspect},"\
  " linked_issue_ids: #{@linked_issue_ids.inspect}, url: #{@url.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/semgrep_web_app/models/protos_ticketing_v1_external_ticket.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} external_slug: #{@external_slug}, id: #{@id}, linked_issue_ids:"\
  " #{@linked_issue_ids}, url: #{@url}, additional_properties: #{@additional_properties}>"
end