Class: SemgrepWebApp::ReviewComment
- Defined in:
- lib/semgrep_web_app/models/review_comment.rb
Overview
External review comment information associated with a finding
Instance Attribute Summary collapse
-
#external_discussion_id ⇒ String
External ID of the review comment or discussion thread.
-
#external_note_id ⇒ String
External ID of the specific note in the review comment discussion thread.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(external_discussion_id: SKIP, external_note_id: SKIP, additional_properties: nil) ⇒ ReviewComment
constructor
A new instance of ReviewComment.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(external_discussion_id: SKIP, external_note_id: SKIP, additional_properties: nil) ⇒ ReviewComment
Returns a new instance of ReviewComment.
42 43 44 45 46 47 48 49 50 |
# File 'lib/semgrep_web_app/models/review_comment.rb', line 42 def initialize(external_discussion_id: SKIP, external_note_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @external_discussion_id = external_discussion_id unless external_discussion_id == SKIP @external_note_id = external_note_id unless external_note_id == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#external_discussion_id ⇒ String
External ID of the review comment or discussion thread
14 15 16 |
# File 'lib/semgrep_web_app/models/review_comment.rb', line 14 def external_discussion_id @external_discussion_id end |
#external_note_id ⇒ String
External ID of the specific note in the review comment discussion thread. Only applicable for GitLab.com, GitLab Self-Managed and Azure DevOps
19 20 21 |
# File 'lib/semgrep_web_app/models/review_comment.rb', line 19 def external_note_id @external_note_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/semgrep_web_app/models/review_comment.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. external_discussion_id = hash.key?('external_discussion_id') ? hash['external_discussion_id'] : SKIP external_note_id = hash.key?('external_note_id') ? hash['external_note_id'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ReviewComment.new(external_discussion_id: external_discussion_id, external_note_id: external_note_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/semgrep_web_app/models/review_comment.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['external_discussion_id'] = 'external_discussion_id' @_hash['external_note_id'] = 'external_note_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/semgrep_web_app/models/review_comment.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/semgrep_web_app/models/review_comment.rb', line 30 def self.optionals %w[ external_discussion_id external_note_id ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
77 78 79 80 81 82 83 |
# File 'lib/semgrep_web_app/models/review_comment.rb', line 77 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 98 |
# File 'lib/semgrep_web_app/models/review_comment.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} external_discussion_id: #{@external_discussion_id.inspect},"\ " external_note_id: #{@external_note_id.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/semgrep_web_app/models/review_comment.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} external_discussion_id: #{@external_discussion_id}, external_note_id:"\ " #{@external_note_id}, additional_properties: #{@additional_properties}>" end |