Class: SemgrepWebApp::ToggleProjectManagedScanRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SemgrepWebApp::ToggleProjectManagedScanRequest
- Defined in:
- lib/semgrep_web_app/models/toggle_project_managed_scan_request.rb
Overview
ToggleProjectManagedScanRequest Model.
Instance Attribute Summary collapse
-
#deployment_slug ⇒ String
Slug of the deployment name.
-
#diff_scan ⇒ ProtosOpenapiV1DiffScan
Slug of the deployment name.
-
#full_scan ⇒ ProtosOpenapiV1FullScan
Slug of the deployment name.
-
#project_name ⇒ String
Name of the project, typically the repository formatted as a path.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(deployment_slug:, project_name:, diff_scan: SKIP, full_scan: SKIP, additional_properties: nil) ⇒ ToggleProjectManagedScanRequest
constructor
A new instance of ToggleProjectManagedScanRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(deployment_slug:, project_name:, diff_scan: SKIP, full_scan: SKIP, additional_properties: nil) ⇒ ToggleProjectManagedScanRequest
Returns a new instance of ToggleProjectManagedScanRequest.
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/semgrep_web_app/models/toggle_project_managed_scan_request.rb', line 54 def initialize(deployment_slug:, project_name:, diff_scan: SKIP, full_scan: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @deployment_slug = deployment_slug @diff_scan = diff_scan unless diff_scan == SKIP @full_scan = full_scan unless full_scan == SKIP @project_name = project_name @additional_properties = additional_properties end |
Instance Attribute Details
#deployment_slug ⇒ String
Slug of the deployment name. Can be found at /deployments, or in your
Settings in the web UI.
15 16 17 |
# File 'lib/semgrep_web_app/models/toggle_project_managed_scan_request.rb', line 15 def deployment_slug @deployment_slug end |
#diff_scan ⇒ ProtosOpenapiV1DiffScan
Slug of the deployment name. Can be found at /deployments, or in your
Settings in the web UI.
20 21 22 |
# File 'lib/semgrep_web_app/models/toggle_project_managed_scan_request.rb', line 20 def diff_scan @diff_scan end |
#full_scan ⇒ ProtosOpenapiV1FullScan
Slug of the deployment name. Can be found at /deployments, or in your
Settings in the web UI.
25 26 27 |
# File 'lib/semgrep_web_app/models/toggle_project_managed_scan_request.rb', line 25 def full_scan @full_scan end |
#project_name ⇒ String
Name of the project, typically the repository formatted as a path.
29 30 31 |
# File 'lib/semgrep_web_app/models/toggle_project_managed_scan_request.rb', line 29 def project_name @project_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/semgrep_web_app/models/toggle_project_managed_scan_request.rb', line 67 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. deployment_slug = hash.key?('deploymentSlug') ? hash['deploymentSlug'] : nil project_name = hash.key?('projectName') ? hash['projectName'] : nil diff_scan = ProtosOpenapiV1DiffScan.from_hash(hash['diff_scan']) if hash['diff_scan'] full_scan = ProtosOpenapiV1FullScan.from_hash(hash['full_scan']) if hash['full_scan'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ToggleProjectManagedScanRequest.new(deployment_slug: deployment_slug, project_name: project_name, diff_scan: diff_scan, full_scan: full_scan, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
32 33 34 35 36 37 38 39 |
# File 'lib/semgrep_web_app/models/toggle_project_managed_scan_request.rb', line 32 def self.names @_hash = {} if @_hash.nil? @_hash['deployment_slug'] = 'deploymentSlug' @_hash['diff_scan'] = 'diff_scan' @_hash['full_scan'] = 'full_scan' @_hash['project_name'] = 'projectName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
50 51 52 |
# File 'lib/semgrep_web_app/models/toggle_project_managed_scan_request.rb', line 50 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
42 43 44 45 46 47 |
# File 'lib/semgrep_web_app/models/toggle_project_managed_scan_request.rb', line 42 def self.optionals %w[ diff_scan full_scan ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 106 |
# File 'lib/semgrep_web_app/models/toggle_project_managed_scan_request.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} deployment_slug: #{@deployment_slug.inspect}, diff_scan:"\ " #{@diff_scan.inspect}, full_scan: #{@full_scan.inspect}, project_name:"\ " #{@project_name.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 98 |
# File 'lib/semgrep_web_app/models/toggle_project_managed_scan_request.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} deployment_slug: #{@deployment_slug}, diff_scan: #{@diff_scan}, full_scan:"\ " #{@full_scan}, project_name: #{@project_name}, additional_properties:"\ " #{@additional_properties}>" end |