Class: SemgrepWebApp::Usage
- Defined in:
- lib/semgrep_web_app/models/usage.rb
Overview
Usage of the vulnerable package in the codebase. Applies to reachable findings
Instance Attribute Summary collapse
-
#external_ticket ⇒ ExternalTicket
External ticket associated with finding.
-
#location ⇒ FindingLocation
Location of the record in a file, as reported by Semgrep.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(external_ticket: SKIP, location: SKIP, additional_properties: nil) ⇒ Usage
constructor
A new instance of Usage.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(external_ticket: SKIP, location: SKIP, additional_properties: nil) ⇒ Usage
Returns a new instance of Usage.
43 44 45 46 47 48 49 50 51 |
# File 'lib/semgrep_web_app/models/usage.rb', line 43 def initialize(external_ticket: SKIP, location: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @external_ticket = external_ticket unless external_ticket == SKIP @location = location unless location == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#external_ticket ⇒ ExternalTicket
External ticket associated with finding
15 16 17 |
# File 'lib/semgrep_web_app/models/usage.rb', line 15 def external_ticket @external_ticket end |
#location ⇒ FindingLocation
Location of the record in a file, as reported by Semgrep. If null, then the information does not exist or lacks integrity (older or broken scans)
20 21 22 |
# File 'lib/semgrep_web_app/models/usage.rb', line 20 def location @location end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/semgrep_web_app/models/usage.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. external_ticket = ExternalTicket.from_hash(hash['external_ticket']) if hash['external_ticket'] location = FindingLocation.from_hash(hash['location']) if hash['location'] # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Usage.new(external_ticket: external_ticket, location: location, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/semgrep_web_app/models/usage.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['external_ticket'] = 'external_ticket' @_hash['location'] = 'location' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/semgrep_web_app/models/usage.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/semgrep_web_app/models/usage.rb', line 31 def self.optionals %w[ external_ticket location ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
77 78 79 80 81 82 83 |
# File 'lib/semgrep_web_app/models/usage.rb', line 77 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
93 94 95 96 97 |
# File 'lib/semgrep_web_app/models/usage.rb', line 93 def inspect class_name = self.class.name.split('::').last "<#{class_name} external_ticket: #{@external_ticket.inspect}, location:"\ " #{@location.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 90 |
# File 'lib/semgrep_web_app/models/usage.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} external_ticket: #{@external_ticket}, location: #{@location},"\ " additional_properties: #{@additional_properties}>" end |