Class: SemgrepWebApp::DeploymentsServiceApi
- Defined in:
- lib/semgrep_web_app/apis/deployments_service_api.rb
Overview
DeploymentsServiceApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#deployments_service_list_deployments ⇒ ApiResponse
Request the deployments your auth can access.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from SemgrepWebApp::BaseApi
Instance Method Details
#deployments_service_list_deployments ⇒ ApiResponse
Request the deployments your auth can access. Currently available auth scope does not extend over more than one deployment. This endpoint returns the single deployment your token can access. The endpoint additionally returns links to related resources available on this API.
15 16 17 18 19 20 21 22 23 24 25 26 27 |
# File 'lib/semgrep_web_app/apis/deployments_service_api.rb', line 15 def deployments_service_list_deployments @api_call .request(new_request_builder(HttpMethodEnum::GET, '/api/v1/deployments', Server::SEMGREP) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('SemgrepWebToken'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(ProtosOpenapiV1ListDeploymentsResponse.method(:from_hash)) .is_api_response(true)) .execute end |