Class: SemgrepWebApp::Guidance
- Defined in:
- lib/semgrep_web_app/models/guidance.rb
Overview
Remediation guidance generated by Semgrep Assistant
Instance Attribute Summary collapse
-
#instructions ⇒ String
Step-by-step instructions explaining to a developer how to fix the finding.
-
#summary ⇒ String
Short title explaining to a developer how to fix the finding.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(instructions: SKIP, summary: SKIP, additional_properties: nil) ⇒ Guidance
constructor
A new instance of Guidance.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(instructions: SKIP, summary: SKIP, additional_properties: nil) ⇒ Guidance
Returns a new instance of Guidance.
43 44 45 46 47 48 49 50 51 |
# File 'lib/semgrep_web_app/models/guidance.rb', line 43 def initialize(instructions: SKIP, summary: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @instructions = instructions unless instructions == SKIP @summary = summary unless summary == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#instructions ⇒ String
Step-by-step instructions explaining to a developer how to fix the finding. AI generated content, review carefully
15 16 17 |
# File 'lib/semgrep_web_app/models/guidance.rb', line 15 def instructions @instructions end |
#summary ⇒ String
Short title explaining to a developer how to fix the finding. AI generated content, review carefully
20 21 22 |
# File 'lib/semgrep_web_app/models/guidance.rb', line 20 def summary @summary end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/semgrep_web_app/models/guidance.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. instructions = hash.key?('instructions') ? hash['instructions'] : SKIP summary = hash.key?('summary') ? hash['summary'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. Guidance.new(instructions: instructions, summary: summary, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/semgrep_web_app/models/guidance.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['instructions'] = 'instructions' @_hash['summary'] = 'summary' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/semgrep_web_app/models/guidance.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/semgrep_web_app/models/guidance.rb', line 31 def self.optionals %w[ instructions summary ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
76 77 78 79 80 81 82 |
# File 'lib/semgrep_web_app/models/guidance.rb', line 76 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 96 |
# File 'lib/semgrep_web_app/models/guidance.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} instructions: #{@instructions.inspect}, summary: #{@summary.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
85 86 87 88 89 |
# File 'lib/semgrep_web_app/models/guidance.rb', line 85 def to_s class_name = self.class.name.split('::').last "<#{class_name} instructions: #{@instructions}, summary: #{@summary},"\ " additional_properties: #{@additional_properties}>" end |