Class: SemgrepWebApp::ProtosOpenapiV1CreateTicketResponseTicketCreationSuccess

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_success.rb

Overview

ProtosOpenapiV1CreateTicketResponseTicketCreationSuccess Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(external_slug: SKIP, issue_ids: SKIP, ticket_id: SKIP, ticket_url: SKIP, additional_properties: nil) ⇒ ProtosOpenapiV1CreateTicketResponseTicketCreationSuccess

Returns a new instance of ProtosOpenapiV1CreateTicketResponseTicketCreationSuccess.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_success.rb', line 53

def initialize(external_slug: SKIP, issue_ids: SKIP, ticket_id: SKIP,
               ticket_url: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @external_slug = external_slug unless external_slug == SKIP
  @issue_ids = issue_ids unless issue_ids == SKIP
  @ticket_id = ticket_id unless ticket_id == SKIP
  @ticket_url = ticket_url unless ticket_url == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#external_slugString

The external slug identifier for the ticket

Returns:

  • (String)


14
15
16
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_success.rb', line 14

def external_slug
  @external_slug
end

#issue_idsArray[Integer]

List of issue IDs

Returns:

  • (Array[Integer])


18
19
20
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_success.rb', line 18

def issue_ids
  @issue_ids
end

#ticket_idInteger

The ID of the created ticket

Returns:

  • (Integer)


22
23
24
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_success.rb', line 22

def ticket_id
  @ticket_id
end

#ticket_urlString

The URL of the created ticket

Returns:

  • (String)


26
27
28
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_success.rb', line 26

def ticket_url
  @ticket_url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_success.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  external_slug = hash.key?('external_slug') ? hash['external_slug'] : SKIP
  issue_ids = hash.key?('issue_ids') ? hash['issue_ids'] : SKIP
  ticket_id = hash.key?('ticket_id') ? hash['ticket_id'] : SKIP
  ticket_url = hash.key?('ticket_url') ? hash['ticket_url'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ProtosOpenapiV1CreateTicketResponseTicketCreationSuccess.new(external_slug: external_slug,
                                                               issue_ids: issue_ids,
                                                               ticket_id: ticket_id,
                                                               ticket_url: ticket_url,
                                                               additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_success.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['external_slug'] = 'external_slug'
  @_hash['issue_ids'] = 'issue_ids'
  @_hash['ticket_id'] = 'ticket_id'
  @_hash['ticket_url'] = 'ticket_url'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_success.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_success.rb', line 39

def self.optionals
  %w[
    external_slug
    issue_ids
    ticket_id
    ticket_url
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
104
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_success.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} external_slug: #{@external_slug.inspect}, issue_ids: #{@issue_ids.inspect},"\
  " ticket_id: #{@ticket_id.inspect}, ticket_url: #{@ticket_url.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
96
# File 'lib/semgrep_web_app/models/protos_openapi_v1_create_ticket_response_ticket_creation_success.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} external_slug: #{@external_slug}, issue_ids: #{@issue_ids}, ticket_id:"\
  " #{@ticket_id}, ticket_url: #{@ticket_url}, additional_properties:"\
  " #{@additional_properties}>"
end